This function allows using a set of labelled time series as input to the machine learning models. The attributes used to train the model are the series themselves. It extracts the time series from a sits tibble and "spreads" them in time to produce a tibble with distances.
.sits_distances(data)Data.table where columns have the reference label and the time series values as distances.
Tibble with time series data and metadata.
Rolf Simoes, [email protected]
Gilberto Camara, [email protected]