Adaptation of the caret::print.confusionMatrix method for the more common usage in Earth Observation.
Usage
# S3 method for class 'sits_area_accuracy'
print(x, ..., digits = 2L)Author
Gilberto Camara, gilberto.camara@inpe.br
Adaptation of the caret::print.confusionMatrix method for the more common usage in Earth Observation.
# S3 method for class 'sits_area_accuracy'
print(x, ..., digits = 2L)Gilberto Camara, gilberto.camara@inpe.br